@@ -118,12 +118,40 @@ MainWindow::MainWindow(QWidget *parent):
     connect(library, SIGNAL(upgrading(const QString &)),
             this, SLOT(onUpgrading(const QString &)));
     connect(library, SIGNAL(endUpgrade()), this, SLOT(onEndUpgrade()));
-#ifndef Q_OS_SYMBIAN
-    connect(library, SIGNAL(beginLoad(int)), this, SLOT(onBeginLoad(int)));
-    connect(library, SIGNAL(loading(const QString &)),
-            this, SLOT(onLoading(const QString &)));
-    connect(library, SIGNAL(endLoad()), this, SLOT(onEndLoad()));
+
+    // Handle loading book parts
+    connect(view, SIGNAL(partLoadStart(int)), this, SLOT(onPartLoadStart()));
+    connect(view, SIGNAL(partLoadEnd(int)), this, SLOT(onPartLoadEnd(int)));
+
+    // Handle progress
+    connect(view, SIGNAL(progress(qreal)), progress, SLOT(setProgress(qreal)));
+
+    // Shadow window for full screen reading
+    fullScreenWindow = new FullScreenWindow(this);
+    connect(fullScreenWindow, SIGNAL(restore()), this, SLOT(showRegular()));
+
+    // Handle settings changes
+    connect(Settings::instance(), SIGNAL(valueChanged(const QString &)),
+            this, SLOT(onSettingsChanged(const QString &)));
+
+    // Handle book view buttons
+    connect(nextButton, SIGNAL(triggered()), this, SLOT(goToNextPage()));
+    connect(previousButton, SIGNAL(triggered()), this, SLOT(goToPreviousPage()));
+
+    // Adopt view, show window
+    showRegular();
+
+#ifdef DORIAN_TEST_MODEL
+    (void)new ModelTest(Library::instance(), this);
 #endif
+}
+
+void MainWindow::initialize()
+{
+    TRACE;
+    Library *library = Library::instance();
+
+    // Upgrade library if needed, then load it
     library->upgrade();
     library->load();
 
@@ -146,39 +174,11 @@ MainWindow::MainWindow(QWidget *parent):
             library->setNowReading(library->index(0));
         }
     }
-
-    // Handle loading book parts
-    connect(view, SIGNAL(partLoadStart(int)), this, SLOT(onPartLoadStart()));
-    connect(view, SIGNAL(partLoadEnd(int)), this, SLOT(onPartLoadEnd(int)));
-
-    // Handle progress
-    connect(view, SIGNAL(progress(qreal)), progress, SLOT(setProgress(qreal)));
-
-    // Shadow window for full screen reading
-    fullScreenWindow = new FullScreenWindow(this);
-    connect(fullScreenWindow, SIGNAL(restore()), this, SLOT(showRegular()));
-
-    // Handle settings changes
-    Settings *settings = Settings::instance();
-    connect(settings, SIGNAL(valueChanged(const QString &)),
-            this, SLOT(onSettingsChanged(const QString &)));
-    settings->setValue("orientation", settings->value("orientation"));
-    settings->setValue("lightson", settings->value("lightson"));
-
-    // Handle book view buttons
-    connect(nextButton, SIGNAL(triggered()), this, SLOT(goToNextPage()));
-    connect(previousButton, SIGNAL(triggered()), this, SLOT(goToPreviousPage()));
-
-    // Adopt view, show window
-    showRegular();
-
-#ifdef DORIAN_TEST_MODEL
-    (void)new ModelTest(Library::instance(), this);
-#endif
 }
 
 void MainWindow::onCurrentBookChanged()
 {
+    TRACE;
     setCurrentBook(Library::instance()->nowReading());
 }
 
@@ -219,9 +219,6 @@ void MainWindow::showRegular()
     show();
 #if defined(Q_OS_SYMBIAN)
     activateWindow();
-#elif defined(Q_WS_MAEMO_5)
-    // FIXME: This is ugly.
-    view->restoreLastBookmark();
 #endif
     progress->flash();
     nextButton->flash();
@@ -317,11 +314,11 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
 void MainWindow::onSettingsChanged(const QString &key)
 {
-    TRACE;
-    qDebug() << key;
 #if defined(Q_WS_MAEMO_5)
     if (key == "orientation") {
-        QString value = Settings::instance()->value(key).toString();
+        QString value = Settings::instance()->value(key,
+            Platform::instance()->defaultOrientation()).toString();
+        qDebug() << "MainWindow::onSettingsChanged: orientation" << value;
         if (value == "portrait") {
             setAttribute(Qt::WA_Maemo5LandscapeOrientation, false);
             setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
@@ -331,18 +328,21 @@ void MainWindow::onSettingsChanged(const QString &key)
         }
     } else if (key == "lightson") {
         bool enable = Settings::instance()->value(key, false).toBool();
+        qDebug() << "MainWindow::onSettingsChanged: lightson" << enable;
         killTimer(preventBlankingTimer);
         if (enable) {
             preventBlankingTimer = startTimer(29 * 1000);
         }
     }
+#else
+    Q_UNUSED(key);
 #endif // Q_WS_MAEMO_5
 }
 
 void MainWindow::onPartLoadStart()
 {
     TRACE;
-    Platform::showBusy(this, true);
+    Platform::instance()->showBusy(this, true);
 }
 
 void MainWindow::onPartLoadEnd(int index)
@@ -359,14 +359,14 @@ void MainWindow::onPartLoadEnd(int index)
             enableNext = true;
         }
     }
-    Platform::showBusy(this, false);
+    Platform::instance()->showBusy(this, false);
 }
 
 void MainWindow::onAddBookmark(const QString &note)
 {
     TRACE;
     view->addBookmark(note);
-    Platform::information(tr("Bookmarked current position"), this);
+    Platform::instance()->information(tr("Bookmarked current position"), this);
 }
 
 void MainWindow::onGoToBookmark(int index)
@@ -437,6 +437,12 @@ void MainWindow::resizeEvent(QResizeEvent *e)
         toolBar->height(), TranslucentButton::pixels, TranslucentButton::pixels);
 #endif // Q_WS_MAEMO_5
     qDebug() << "previousButton geometry" << previousButton->geometry();
+
+#ifdef Q_WS_MAEMO_5
+    // This is needed on Maemo, in order not to lose current reading position
+    // after orientation change
+    QTimer::singleShot(250, view, SLOT(restoreLastBookmark()));
+#endif
     previousButton->flash();
     nextButton->flash();
     QMainWindow::resizeEvent(e);
@@ -446,6 +452,7 @@ void MainWindow::about()
 {
     Dyalog *aboutDialog = new Dyalog(this, false);
     aboutDialog->setWindowTitle(tr("About Dorian"));
+    QString version = Platform::instance()->version();
     QLabel *label = new QLabel(aboutDialog);
     label->setTextFormat(Qt::RichText);
     label->setOpenExternalLinks(true);
@@ -454,7 +461,7 @@ void MainWindow::about()
         "Akos Polster &lt;akos@pipacs.com&gt;<br>"
         "Licensed under GNU General Public License, Version 3<br>"
         "Source code:<br><a href='https://garage.maemo.org/projects/dorian/'>"
-        "garage.maemo.org/projects/dorian</a>").arg(Platform::version()));
+        "garage.maemo.org/projects/dorian</a>").arg(version));
     aboutDialog->addWidget(label);
     aboutDialog->addStretch();
     aboutDialog->show();
