@@ -6,7 +6,7 @@
 
 SearchDialog::SearchDialog(QWidget *parent): Dyalog(parent)
 {
-    setWindowTitle(tr("SearchDialog"));
+    setWindowTitle(tr("Search the Web"));
 
     QLabel *titleLabel = new QLabel(tr("Title:"), this);
     title = new QLineEdit(this);
@@ -23,7 +23,7 @@ SearchDialog::SearchDialog(QWidget *parent): Dyalog(parent)
 
 Search::Query SearchDialog::query()
 {
-    Trace t("SearchDialog::query");
+    TRACE;
     Search::Query ret;
     ret.title = title->text();
     ret.author = author->text();
